@@ -5,11 +5,16 @@
 ###################################################
 options(
   SweaveHooks=list(
-    fig=function() par(
-      mar=c(3.1, 3.1, 2.1, 2.1), mgp = c(1.5, 0.25, 0), tcl = -0.25
-    )),
+    fig=function(){
+      par(
+        mar=c(3.1, 3.1, 2.1, 2.1), mgp = c(1.5, 0.25, 0), tcl = -0.25
+      )
+    }
+  ),
   width=80, str=strOptions(strict.width="cut"),
-  digits=5)
+  digits=5
+)
+grDevices::pdf.options( useDingbats = FALSE )
 t.t <- (1:9)
 t.tick.locations <- c(
   t.t*0.0001, t.t*0.001, t.t*0.01, t.t*0.1, t.t, t.t*10, t.t*100, t.t*1000,
@@ -22,16 +27,12 @@ t.tick.labels <- as.character(
     t.tl*10000,  t.tl*100000,  t.tl*1000000
   )
 )
+# my.ncores <- parallel::detectCores()     # <<- Anpassen!!
+my.ncores <- 1     # <<- Anpassen!!
 
 
 ###################################################
-### code chunk number 2: meuse-zinc-load (eval = FALSE)
-###################################################
-## if(file.exists("r_meuse_zinc_objects.RData")) load("r_meuse_zinc_objects.RData")
-
-
-###################################################
-### code chunk number 3: meuse-data
+### code chunk number 2: meuse-data
 ###################################################
 data(meuse, package="sp")
 levels(meuse$ffreq) <- paste("ffreq", levels(meuse$ffreq), sep="")
@@ -40,7 +41,7 @@ str(meuse)
 
 
 ###################################################
-### code chunk number 4: meuse-zinc-eda-plot-1
+### code chunk number 3: meuse-zinc-eda-plot-1
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 library(lattice)
@@ -52,7 +53,7 @@ legend("topright", col=c(rep(1, nlevels(meuse$ffreq)), 1:nlevels(meuse$soil)),
 
 
 ###################################################
-### code chunk number 5: meuse-zinc-eda-plot-2
+### code chunk number 4: meuse-zinc-eda-plot-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 xyplot(log(zinc)~dist | ffreq, meuse, groups=soil, panel=function(x, y, ...){
@@ -62,7 +63,7 @@ xyplot(log(zinc)~dist | ffreq, meuse, groups=soil, panel=function(x, y, ...){
 
 
 ###################################################
-### code chunk number 6: meuse-zinc-eda-plot-3
+### code chunk number 5: meuse-zinc-eda-plot-3
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 xyplot(log(zinc)~sqrt(dist) | ffreq, meuse, groups=soil, panel=function(x, y, ...){
@@ -73,21 +74,21 @@ xyplot(log(zinc)~sqrt(dist) | ffreq, meuse, groups=soil, panel=function(x, y, ..
 
 
 ###################################################
-### code chunk number 7: meuse-zinc-lm
+### code chunk number 6: meuse-zinc-lm
 ###################################################
 r.lm <- lm(log(zinc)~sqrt(dist)+ffreq, meuse)
 summary(r.lm)
 
 
 ###################################################
-### code chunk number 8: meuse-zinc-lm-resdiag
+### code chunk number 7: meuse-zinc-lm-resdiag
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(2, 2)); plot(r.lm); par(op)
 
 
 ###################################################
-### code chunk number 9: meuse-zinc-lm-res-sv-1
+### code chunk number 8: meuse-zinc-lm-res-sv-1
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 library(georob)
@@ -98,7 +99,7 @@ plot(sample.variogram(residuals(r.lm), locations=meuse[, c("x","y")],
 
 
 ###################################################
-### code chunk number 10: meuse-zinc-lm-res-sv-2
+### code chunk number 9: meuse-zinc-lm-res-sv-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 library(georob)
@@ -111,13 +112,13 @@ lines(r.sv.spher <- fit.variogram.model(r.sv, variogram.mode="RMspheric",
 
 
 ###################################################
-### code chunk number 11: meuse-zinc-lm-res-spher
+### code chunk number 10: meuse-zinc-lm-res-spher
 ###################################################
 summary(r.sv.spher)
 
 
 ###################################################
-### code chunk number 12: meuse-zinc-georob-reml
+### code chunk number 11: meuse-zinc-georob-reml
 ###################################################
 r.georob.m0.spher.reml <- georob(log(zinc)~sqrt(dist)+ffreq, meuse, locations=~x+y,
   variogram.model="RMspheric", param=c(variance=0.1, nugget=0.05, scale=1000), 
@@ -125,27 +126,27 @@ r.georob.m0.spher.reml <- georob(log(zinc)~sqrt(dist)+ffreq, meuse, locations=~x
 
 
 ###################################################
-### code chunk number 13: meuse-zinc-summary-georob-reml
+### code chunk number 12: meuse-zinc-summary-georob-reml
 ###################################################
 summary(r.georob.m0.spher.reml)
 
 
 ###################################################
-### code chunk number 14: meuse-zinc-proflik-reml-scale-1a (eval = FALSE)
+### code chunk number 13: meuse-zinc-proflik-reml-scale-1a (eval = FALSE)
 ###################################################
 ## r.prfl.m0.spher.reml.scale <- profilelogLik(r.georob.m0.spher.reml,
 ##   values=data.frame(scale=seq(500, 5000, by=50)))
 
 
 ###################################################
-### code chunk number 15: meuse-zinc-proflik-reml-scale-1b
+### code chunk number 14: meuse-zinc-proflik-reml-scale-1b
 ###################################################
 r.prfl.m0.spher.reml.scale <- profilelogLik(r.georob.m0.spher.reml,
-  values=data.frame(scale=seq(500, 5000, by=50)), ncores=1)
+  values=data.frame(scale=seq(500, 5000, by=50)), ncores=my.ncores)
 
 
 ###################################################
-### code chunk number 16: meuse-zinc-proflik-reml-scale-2
+### code chunk number 15: meuse-zinc-proflik-reml-scale-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(loglik~scale, r.prfl.m0.spher.reml.scale, type="l")
@@ -154,7 +155,7 @@ abline(h=r.georob.m0.spher.reml$loglik - 0.5*qchisq(0.95, 1), lty="dotted")
 
 
 ###################################################
-### code chunk number 17: meuse-zinc-proflik-reml-scale-3
+### code chunk number 16: meuse-zinc-proflik-reml-scale-3
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(1,2), cex=0.66)
@@ -164,13 +165,13 @@ par(op)
 
 
 ###################################################
-### code chunk number 18: meuse-zinc-georob-reml-waldtest-1
+### code chunk number 17: meuse-zinc-georob-reml-waldtest-1
 ###################################################
 waldtest(r.georob.m0.spher.reml, .~.-ffreq)
 
 
 ###################################################
-### code chunk number 19: meuse-zinc-georob-reml-multcomp
+### code chunk number 18: meuse-zinc-georob-reml-multcomp
 ###################################################
 library(multcomp)
 summary(glht(r.georob.m0.spher.reml, 
@@ -179,39 +180,39 @@ summary(glht(r.georob.m0.spher.reml,
 
 
 ###################################################
-### code chunk number 20: meuse-zinc-georob-reml-waldtest-2
+### code chunk number 19: meuse-zinc-georob-reml-waldtest-2
 ###################################################
 waldtest(r.georob.m0.spher.reml, .~.+sqrt(dist):ffreq)
 
 
 ###################################################
-### code chunk number 21: meuse-zinc-georob-reml-waldtest-3
+### code chunk number 20: meuse-zinc-georob-reml-waldtest-3
 ###################################################
 waldtest(r.georob.m0.spher.reml, .~.+soil)
 
 
 ###################################################
-### code chunk number 22: meuse-zinc-georob-reml-step-1
+### code chunk number 21: meuse-zinc-georob-reml-step-1
 ###################################################
 step(r.georob.m0.spher.reml, scope=log(zinc)~ffreq*sqrt(dist)+soil)
 
 
 ###################################################
-### code chunk number 23: meuse-zinc-georob-reml-step-2
+### code chunk number 22: meuse-zinc-georob-reml-step-2
 ###################################################
 step(r.georob.m0.spher.reml, scope=log(zinc)~ffreq*sqrt(dist)+soil, 
   fixed.add1.drop1=FALSE)
 
 
 ###################################################
-### code chunk number 24: meuse-zinc-georob-ml
+### code chunk number 23: meuse-zinc-georob-ml
 ###################################################
 r.georob.m0.spher.ml <- update(r.georob.m0.spher.reml, 
   control=control.georob(ml.method="ML"))
 
 
 ###################################################
-### code chunk number 25: meuse-zinc-georob-aic
+### code chunk number 24: meuse-zinc-georob-aic
 ###################################################
 extractAIC(r.georob.m0.spher.reml, REML=TRUE)
 extractAIC(r.georob.m0.spher.ml)
@@ -219,7 +220,7 @@ r.georob.m0.spher.ml
 
 
 ###################################################
-### code chunk number 26: meuse-zinc-cv-1 (eval = FALSE)
+### code chunk number 25: meuse-zinc-cv-1 (eval = FALSE)
 ###################################################
 ## r.cv.m0.spher.reml <- cv(r.georob.m0.spher.reml, seed=3245, lgn=TRUE)
 ## r.georob.m1.spher.reml <- update(r.georob.m0.spher.reml, .~.-ffreq)
@@ -227,22 +228,22 @@ r.georob.m0.spher.ml
 
 
 ###################################################
-### code chunk number 27: meuse-zinc-cv-2
+### code chunk number 26: meuse-zinc-cv-2
 ###################################################
-r.cv.m0.spher.reml <- cv(r.georob.m0.spher.reml, seed=3245, lgn=TRUE, ncores=1)
+r.cv.m0.spher.reml <- cv(r.georob.m0.spher.reml, seed=3245, lgn=TRUE, ncores=my.ncores)
 r.georob.m1.spher.reml <- update(r.georob.m0.spher.reml, .~.-ffreq)
-r.cv.m1.spher.reml <- cv(r.georob.m1.spher.reml, seed=3245, lgn=TRUE, ncores=1)
+r.cv.m1.spher.reml <- cv(r.georob.m1.spher.reml, seed=3245, lgn=TRUE, ncores=my.ncores)
 
 
 ###################################################
-### code chunk number 28: meuse-zinc-cv-summary
+### code chunk number 27: meuse-zinc-cv-summary
 ###################################################
 summary(r.cv.m0.spher.reml)
 summary(r.cv.m1.spher.reml)
 
 
 ###################################################
-### code chunk number 29: meuse-zinc-cv-plot
+### code chunk number 28: meuse-zinc-cv-plot
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(3,2))
@@ -264,7 +265,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 30: meuse-zinc-georob-plot
+### code chunk number 29: meuse-zinc-georob-plot
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(2,2), cex=0.66)
@@ -277,7 +278,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 31: meuse-zinc-meuse-grid
+### code chunk number 30: meuse-zinc-meuse-grid
 ###################################################
 data(meuse.grid)
 levels(meuse.grid$ffreq) <- paste("ffreq", levels(meuse.grid$ffreq), sep="")
@@ -287,7 +288,7 @@ gridded(meuse.grid) <- TRUE
 
 
 ###################################################
-### code chunk number 32: meuse-zinc-meuse-point-kriging
+### code chunk number 31: meuse-zinc-meuse-point-Kriging
 ###################################################
 r.pk <- predict(r.georob.m0.spher.reml, newdata=meuse.grid,
   control=control.predict.georob(extended.output=TRUE))
@@ -295,13 +296,13 @@ r.pk <- lgnpp(r.pk)
 
 
 ###################################################
-### code chunk number 33: meuse-zinc-meuse-point-kriging-lgn
+### code chunk number 32: meuse-zinc-meuse-point-Kriging-lgn
 ###################################################
 str(r.pk)
 
 
 ###################################################
-### code chunk number 34: meuse-zinc-point-kriging-plot
+### code chunk number 33: meuse-zinc-point-Kriging-plot
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 brks <- c(25, 50, 75, 100, 150, 200, seq(500, 3500,by=500))
@@ -314,34 +315,34 @@ plot(upr, position=c(2/3, 0, 1, 1), more=FALSE)
 
 
 ###################################################
-### code chunk number 35: meuse-zinc-block-kriging
+### code chunk number 34: meuse-zinc-block-Kriging
 ###################################################
 data(meuse.blocks, package="constrainedKriging")
 str(meuse.blocks, max=2)
 
 
 ###################################################
-### code chunk number 36: meuse-zinc-meuse-block-kriging-1a (eval = FALSE)
+### code chunk number 35: meuse-zinc-meuse-block-Kriging-1a (eval = FALSE)
 ###################################################
 ## r.bk <- predict(r.georob.m1.spher.reml, newdata=meuse.blocks,
 ##   control=control.predict.georob(extended.output=TRUE, pwidth=25, pheight=25, mmax=25))
 
 
 ###################################################
-### code chunk number 37: meuse-zinc-meuse-block-kriging-1b
+### code chunk number 36: meuse-zinc-meuse-block-Kriging-1b
 ###################################################
 r.bk <- predict(r.georob.m1.spher.reml, newdata=meuse.blocks,
   control=control.predict.georob(extended.output=TRUE, pwidth=25, pheight=25))
 
 
 ###################################################
-### code chunk number 38: meuse-zinc-meuse-block-kriging-2
+### code chunk number 37: meuse-zinc-meuse-block-Kriging-2
 ###################################################
 r.bk <- lgnpp(r.bk, newdata=meuse.grid)
 
 
 ###################################################
-### code chunk number 39: meuse-zinc-block-kriging-plot
+### code chunk number 38: meuse-zinc-block-Kriging-plot
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 brks <- c(25, 50, 75, 100, 150, 200, seq(500, 3500,by=500))
@@ -354,7 +355,7 @@ plot(upr, position=c(2/3, 0, 1, 1), more=FALSE)
 
 
 ###################################################
-### code chunk number 40: meuse-zinc-block-kriging-blocks
+### code chunk number 39: meuse-zinc-block-Kriging-blocks
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 ## define blocks
@@ -374,7 +375,7 @@ plot(geometry(blks), add=TRUE, col=2)
 
 
 ###################################################
-### code chunk number 41: meuse-zinc-block-kriging-3
+### code chunk number 40: meuse-zinc-block-Kriging-3
 ###################################################
 r.blks <- predict(r.georob.m1.spher.reml, newdata=blks, 
   control=control.predict.georob(extended.output=TRUE, pwidth=800, pheight=800))
@@ -382,7 +383,7 @@ r.blks <- lgnpp(r.blks, newdata=meuse.grid)
 
 
 ###################################################
-### code chunk number 42: <meuse-zinc-block-kriging-4a
+### code chunk number 41: <meuse-zinc-block-Kriging-4a
 ###################################################
 t.pk <- predict(r.georob.m0.spher.reml, newdata=as.data.frame(meuse.grid),
   control=control.predict.georob(extended.output=TRUE, full.covmat=TRUE))
@@ -390,7 +391,7 @@ str(t.pk)
 
 
 ###################################################
-### code chunk number 43: meuse-zinc-block-kriging-5
+### code chunk number 42: meuse-zinc-block-Kriging-5
 ###################################################
 ## index defining to which block the points predictions belong
 ind <- over(geometry(meuse.grid), geometry(blks))
@@ -410,39 +411,26 @@ r.blks <- cbind( r.blks, tmp)
 
 
 ###################################################
-### code chunk number 44: meuse-zinc-block-kriging-6
+### code chunk number 43: meuse-zinc-block-Kriging-6
 ###################################################
 r.blks@data[, c("lgn.pred", "opt.pred", "lgn.se", "opt.se")]
 
 
 ###################################################
-### code chunk number 45: meuse-zinc-cleanup-1
+### code chunk number 44: meuse-zinc-cleanup-1
 ###################################################
 palette("default")
 
 
 ###################################################
-### code chunk number 46: meuse-zinc-cleanup-2 (eval = FALSE)
-###################################################
-## save(list=ls(pattern="^r\\."), file="r_meuse_zinc_objects.RData")
-## rm(list=ls(pattern="^r\\."))
-
-
-###################################################
-### code chunk number 47: ash-load (eval = FALSE)
-###################################################
-## if(file.exists("r_coalash_objects.RData")) load("r_coalash_objects.RData")
-
-
-###################################################
-### code chunk number 48: ash-data
+### code chunk number 45: ash-data
 ###################################################
 data(coalash, package="gstat")
 summary(coalash)
 
 
 ###################################################
-### code chunk number 49: ash-centred-bubbleplot1
+### code chunk number 46: ash-centred-bubbleplot1
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(y~x, coalash, cex=sqrt(abs(coalash - median(coalash))), 
@@ -453,7 +441,7 @@ legend("topleft", pch=1, col=c("blue", "red"), legend=c("< 0", "> 0"), bty="n")
 
 
 ###################################################
-### code chunk number 50: ash-coords-scatterplot
+### code chunk number 47: ash-coords-scatterplot
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(1,2))
@@ -463,14 +451,14 @@ par(op)
 
 
 ###################################################
-### code chunk number 51: ash-centerd-qqnorm
+### code chunk number 48: ash-centerd-qqnorm
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 qqnorm(coalash$coalash)
 
 
 ###################################################
-### code chunk number 52: ash-lmrob
+### code chunk number 49: ash-lmrob
 ###################################################
 library(robustbase)
 r.lmrob <- lmrob(coalash~x+y, coalash)
@@ -478,7 +466,7 @@ summary(r.lmrob)
 
 
 ###################################################
-### code chunk number 53: ash-diag-lmrob
+### code chunk number 50: ash-diag-lmrob
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(2,2))
@@ -487,7 +475,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 54: ash-sv-res-lmrob-iso
+### code chunk number 51: ash-sv-res-lmrob-iso
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 library(georob)
@@ -506,7 +494,7 @@ legend("bottomright", pch=1:4, col=c("black", "blue", "cyan", "orange"),
 
 
 ###################################################
-### code chunk number 55: ash-sv-res-lmrob-aniso
+### code chunk number 52: ash-sv-res-lmrob-aniso
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 r.sv <- sample.variogram(residuals(r.lmrob), locations=coalash[, c("x","y")],
@@ -521,45 +509,45 @@ legend("bottomright", pch=c(1, 3), col=c("blue", "orange"),
 
 
 ###################################################
-### code chunk number 56: ash-georob-robust-1
+### code chunk number 53: ash-georob-robust-1
 ###################################################
 r.georob.m0.exp.c2 <- georob(coalash~x+y, coalash, locations=~x+y, 
   variogram.model="RMexp", param=c(variance=0.1, nugget=0.9, scale=1))
 
 
 ###################################################
-### code chunk number 57: ash-summary-georob-robust-1
+### code chunk number 54: ash-summary-georob-robust-1
 ###################################################
 summary(r.georob.m0.exp.c2)
 
 
 ###################################################
-### code chunk number 58: ash-waldtest-quadratic-robust
+### code chunk number 55: ash-waldtest-quadratic-robust
 ###################################################
 waldtest(update(r.georob.m0.exp.c2, .~.+I(x^2)+I(y^2)+I(x*y)), r.georob.m0.exp.c2)
 
 
 ###################################################
-### code chunk number 59: ash-georob-robust-2
+### code chunk number 56: ash-georob-robust-2
 ###################################################
 r.georob.m1.exp.c2 <- update(r.georob.m0.exp.c2, .~.-y)
 
 
 ###################################################
-### code chunk number 60: ash-summary-georob-robust-2
+### code chunk number 57: ash-summary-georob-robust-2
 ###################################################
 r.georob.m1.exp.c2
 
 
 ###################################################
-### code chunk number 61: ash-georob-robust-3
+### code chunk number 58: ash-georob-robust-3
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(r.georob.m1.exp.c2, lag.dist.def=1, max.lag=10, estimator="qn", col="blue")
 
 
 ###################################################
-### code chunk number 62: ash-diag-georob-robust-2-1
+### code chunk number 59: ash-diag-georob-robust-2-1
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(2,2))
@@ -571,7 +559,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 63: ash-rw-georob-robust-2-1
+### code chunk number 60: ash-rw-georob-robust-2-1
 ###################################################
 round(cbind(coalash[, c("x", "y")], 
   rweights=r.georob.m1.exp.c2[["rweights"]])[c(15, 50, 63, 73, 88, 111, 192),],
@@ -579,7 +567,7 @@ round(cbind(coalash[, c("x", "y")],
 
 
 ###################################################
-### code chunk number 64: ash-rw-georob-robust-2-1
+### code chunk number 61: ash-rw-georob-robust-2-1
 ###################################################
 sel <- r.georob.m1.exp.c2[["rweights"]] <= 0.8 & 
   !1:nrow(coalash) %in% c(15, 50, 63, 73, 88, 111, 192)
@@ -589,7 +577,7 @@ round(cbind(coalash[, c("x", "y")],
 
 
 ###################################################
-### code chunk number 65: ash-diag-georob-robust-2-2
+### code chunk number 62: ash-diag-georob-robust-2-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(y~x, coalash, cex=sqrt(abs(residuals(r.georob.m1.exp.c2))), 
@@ -600,30 +588,32 @@ legend("topleft", pch=1, col=c("blue", "red"), legend=c("< 0", "> 0"), bty="n")
 
 
 ###################################################
-### code chunk number 66: ash-georob-gaussian-1
+### code chunk number 63: ash-georob-gaussian-1
 ###################################################
 r.georob.m1.exp.c1000 <- update(r.georob.m1.exp.c2, tuning.psi=1000)
 
 
 ###################################################
-### code chunk number 67: ash-georob-summary-gaussian-1
+### code chunk number 64: ash-georob-summary-gaussian-1
 ###################################################
 summary(r.georob.m1.exp.c1000)
 
 
 ###################################################
-### code chunk number 68: ash-georob-gaussian-2
+### code chunk number 65: ash-georob-gaussian-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(r.georob.m1.exp.c1000, lag.dist.def=1, max.lag=10, estimator="matheron")
 plot(r.georob.m1.exp.c2, lag.dist.def=1, max.lag=10, estimator="qn", add = TRUE, 
   col="blue")
-legend("bottomright", lt=1, col=c("black","blue"), 
-  legend =c("Gaussian REML (c=1000)", "robust REML (c=2)"), bty="n")
+plot(update(r.georob.m1.exp.c2, subset=-50), lag.dist.def=1, max.lag=10, estimator="qn", 
+  add = TRUE, col="orange")
+legend("bottomright", lt=1, col=c("black","blue", "orange"), 
+  legend =c("Gaussian REML", "robust REML", "Gaussian REML without outlier (5,6)" ), bty="n")
 
 
 ###################################################
-### code chunk number 69: ash-georob-diag-gaussian-robust-2
+### code chunk number 66: ash-georob-diag-gaussian-robust-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(1,2), cex=5/6)
@@ -640,37 +630,37 @@ abline(0, 1, lty="dotted")
 
 
 ###################################################
-### code chunk number 70: ash-cv-georob-gaussian-robust-1 (eval = FALSE)
+### code chunk number 67: ash-cv-georob-gaussian-robust-1 (eval = FALSE)
 ###################################################
-## r.cv.georob.m1.exp.c2 <- cv(r.georob.m1.exp.c2, seed=1, param=r.georob.m1.exp.c2$param,
+## r.cv.georob.m1.exp.c2 <- cv(r.georob.m1.exp.c2, seed=1,
 ##   control=control.georob(initial.param=FALSE))
 ## r.cv.georob.m1.exp.c1000 <- cv(r.georob.m1.exp.c1000, seed=1)
 
 
 ###################################################
-### code chunk number 71: ash-cv-georob-gaussian-robust-2
+### code chunk number 68: ash-cv-georob-gaussian-robust-2
 ###################################################
-r.cv.georob.m1.exp.c2 <- cv(r.georob.m1.exp.c2, seed=1, param=r.georob.m1.exp.c2$param,
-  control=control.georob(initial.param=FALSE), ncores=1)
-r.cv.georob.m1.exp.c1000 <- cv(r.georob.m1.exp.c1000, seed=1, ncores=1)
+r.cv.georob.m1.exp.c2 <- cv(r.georob.m1.exp.c2, seed=1, 
+  control=control.georob(initial.param=FALSE), ncores=my.ncores)
+r.cv.georob.m1.exp.c1000 <- cv(r.georob.m1.exp.c1000, seed=1, ncores=my.ncores)
 
 
 ###################################################
-### code chunk number 72: ash-cv-georob-subsets
+### code chunk number 69: ash-cv-georob-subsets
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(y~x, r.cv.georob.m1.exp.c2$pred, asp=1, col=subset, pch=as.integer(subset))
 
 
 ###################################################
-### code chunk number 73: ash-summary-cv-georob-gaussian-robust
+### code chunk number 70: ash-summary-cv-georob-gaussian-robust
 ###################################################
 summary(r.cv.georob.m1.exp.c1000, se=TRUE)
 summary(r.cv.georob.m1.exp.c2, se=TRUE)
 
 
 ###################################################
-### code chunk number 74: ash-diag-cv-georob-gaussian-robust
+### code chunk number 71: ash-diag-cv-georob-gaussian-robust
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(3, 2))
@@ -695,7 +685,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 75: ash-kriging-grid
+### code chunk number 72: ash-Kriging-grid
 ###################################################
 coalash.grid <- expand.grid(x=seq(-1, 17, by=0.1),
   y=seq( -1, 24, by=0.1))
@@ -706,31 +696,31 @@ str(coalash.grid, max=2)
 
 
 ###################################################
-### code chunk number 76: ash-pkriging-1 (eval = FALSE)
+### code chunk number 73: ash-pKriging-1 (eval = FALSE)
 ###################################################
 ## r.pk.m1.exp.c2 <- predict(r.georob.m1.exp.c2, newdata=coalash.grid)
 ## r.pk.m1.exp.c1000 <- predict(r.georob.m1.exp.c1000, newdata=coalash.grid)
 
 
 ###################################################
-### code chunk number 77: ash-pkriging-2
+### code chunk number 74: ash-pKriging-2
 ###################################################
-r.pk.m1.exp.c2 <- predict(r.georob.m1.exp.c2, newdata=coalash.grid, control=control.predict.georob(ncores=1))
-r.pk.m1.exp.c1000 <- predict(r.georob.m1.exp.c1000, newdata=coalash.grid, control=control.predict.georob(ncores=1))
+r.pk.m1.exp.c2 <- predict(r.georob.m1.exp.c2, newdata=coalash.grid, control=control.predict.georob(ncores=my.ncores))
+r.pk.m1.exp.c1000 <- predict(r.georob.m1.exp.c1000, newdata=coalash.grid, control=control.predict.georob(ncores=my.ncores))
 
 
 ###################################################
-### code chunk number 78: ash-pkriging-plot-robust-gaussian-1
+### code chunk number 75: ash-pKriging-plot-robust-gaussian-1
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 pred.rob <- spplot(r.pk.m1.exp.c2, "pred", at=seq(8, 12, by=0.25), 
-  main="robust kriging prediction", scales=list(draw=TRUE))
+  main="robust Kriging prediction", scales=list(draw=TRUE))
 pred.gauss <- spplot(r.pk.m1.exp.c1000, "pred", at=seq(8, 12, by=0.25), 
-  main="Gaussian kriging prediction", scales=list(draw=TRUE))
+  main="Gaussian Kriging prediction", scales=list(draw=TRUE))
 se.rob <- spplot(r.pk.m1.exp.c2, "se", at=seq(0.35, 0.65, by=0.025), 
-  main="standard error robust kriging", scales=list(draw=TRUE))
+  main="standard error robust Kriging", scales=list(draw=TRUE))
 se.gauss <- spplot(r.pk.m1.exp.c1000, "se", at=seq(0.35, 0.65, by=0.025), 
-  main="standard error Gaussian kriging", scales=list(draw=TRUE))
+  main="standard error Gaussian Kriging", scales=list(draw=TRUE))
 plot(pred.rob, pos=c(0, 0.5, 0.5, 1), more=TRUE)
 plot(pred.gauss, pos=c(0.5, 0.5, 1, 1), more=TRUE)
 plot(se.rob, pos=c(0, 0, 0.5, 0.5), more=TRUE)
@@ -738,7 +728,7 @@ plot(se.gauss, pos=c(0.5, 0, 1, 0.5), more=FALSE)
 
 
 ###################################################
-### code chunk number 79: ash-pkriging-plot-robust-gaussian-2
+### code chunk number 76: ash-pKriging-plot-robust-gaussian-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 library(lattice)
@@ -746,12 +736,12 @@ library(lattice)
 r.pk.m1.exp.c2$reldiff.pred <- (r.pk.m1.exp.c1000$pred -
   r.pk.m1.exp.c2$pred) / r.pk.m1.exp.c2$pred * 100
 reldiff.pred <- spplot(r.pk.m1.exp.c2, "reldiff.pred", at=-1:7, 
-  main="Gaussian - robust kriging predictions", scales=list(draw=TRUE))
-# ratio kriging variances
+  main="Gaussian - robust Kriging predictions", scales=list(draw=TRUE))
+# ratio Kriging variances
 r.pk.m1.exp.c2$ratio.msep <- r.pk.m1.exp.c1000$se^2 / 
   r.pk.m1.exp.c2$se^2 * 100
 ratio.msep <- spplot(r.pk.m1.exp.c2, "ratio.msep",  at=105:115, 
-  main="ratio of Gaussian to robust kriging variances",scales=list(draw=TRUE))
+  main="ratio of Gaussian to robust Kriging variances",scales=list(draw=TRUE))
 plot(reldiff.pred, pos=c(0, 0, 0.5, 1), more=TRUE)
 #  add bubble plot of centred data colored by "robustness" weights
 rw <- cut(r.georob.m1.exp.c2$rweights, seq(0.2, 1, by = 0.2))
@@ -768,7 +758,7 @@ plot(ratio.msep, pos=c(0.5, 0, 1, 1), more=FALSE)
 
 
 ###################################################
-### code chunk number 80: ash-kriging-polygons
+### code chunk number 77: ash-Kriging-polygons
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 tmp <- expand.grid(x = seq(2.5, 16.5, by=4), y=seq(2, 22, by=4))
@@ -786,7 +776,7 @@ plot(coalash.polygons, col="grey", axes=TRUE); points(y~x, coalash)
 
 
 ###################################################
-### code chunk number 81: ash-bkriging-1
+### code chunk number 78: ash-bKriging-1
 ###################################################
 r.bk.m1.exp.c2 <- predict(r.georob.m1.exp.c2, newdata=coalash.polygons,
   control=control.predict.georob(pwidth=4, pheight=4, full.covmat=TRUE))
@@ -795,20 +785,20 @@ r.bk.m1.exp.c1000 <- predict(r.georob.m1.exp.c1000, newdata=coalash.polygons,
 
 
 ###################################################
-### code chunk number 82: ash-str-bkriging
+### code chunk number 79: ash-str-bKriging
 ###################################################
 str(r.bk.m1.exp.c2, max=2)
 
 
 ###################################################
-### code chunk number 83: ash-gkriging
+### code chunk number 80: ash-gKriging
 ###################################################
 c(pred=mean(r.bk.m1.exp.c2$pred$pred),
   se=sqrt(sum(r.bk.m1.exp.c2$mse.pred))/24)
 
 
 ###################################################
-### code chunk number 84: ash-bkriging-2
+### code chunk number 81: ash-bKriging-2
 ###################################################
 coalash.domain <- rbind(c(0.5,0), c(16.5,0), c(16.5,24), c(0.5,24), c(0.5,0))
 coalash.domain <- SpatialPolygonsDataFrame(
@@ -819,32 +809,20 @@ slot(predict(r.georob.m1.exp.c2, newdata=coalash.domain,
 
 
 ###################################################
-### code chunk number 85: ash-bkriging-plot-robust-gaussian-1
+### code chunk number 82: ash-bKriging-plot-robust-gaussian-1
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 pred.rob <- spplot(r.bk.m1.exp.c2$pred, "pred", at=seq(8, 11, by=0.25), 
-  main="robust kriging prediction", scales=list(draw=TRUE))
+  main="robust Kriging prediction", scales=list(draw=TRUE))
 pred.gauss <- spplot(r.bk.m1.exp.c1000$pred, "pred", at=seq(8, 11, by=0.25), 
-  main="Gaussian kriging prediction", scales=list(draw=TRUE))
+  main="Gaussian Kriging prediction", scales=list(draw=TRUE))
 se.rob <- spplot(r.bk.m1.exp.c2$pred, "se", at=seq(0.15, 0.45, by=0.025), 
-  main="standard error robust kriging", scales=list(draw=TRUE))
+  main="standard error robust Kriging", scales=list(draw=TRUE))
 se.gauss <- spplot(r.bk.m1.exp.c1000$pred, "se", at=seq(0.15, 0.45, by=0.025), 
-  main="standard error Gaussian kriging", scales=list(draw=TRUE))
+  main="standard error Gaussian Kriging", scales=list(draw=TRUE))
 plot(pred.rob, pos=c(0, 0.5, 0.5, 1), more=TRUE)
 plot(pred.gauss, pos=c(0.5, 0.5, 1, 1), more=TRUE)
 plot(se.rob, pos=c(0, 0, 0.5, 0.5), more=TRUE)
 plot(se.gauss, pos=c(0.5, 0, 1, 0.5), more=FALSE)
 
 
-###################################################
-### code chunk number 86: ash-results-save-1
-###################################################
-save(list=ls(pattern="^r\\."), file="r_coalash_objects.RData")
-
-
-###################################################
-### code chunk number 87: ash-rm (eval = FALSE)
-###################################################
-## rm(list=ls(pattern="^r\\."))
-
-
